@@ -1,6 +1,6 @@
 use log::debug;
 use ndarray::{Array1, Array2, ArrayView1};
-use std::{clone, fmt::Display};
+use std::fmt::Display;
 
 #[derive(Debug)]
 pub enum SimplexError {
@@ -12,8 +12,8 @@ pub enum SimplexError {
 
 pub struct Table {
     pub table: Array2<f64>,
-    pub supp_var: Vec<String>,
     pub base_var: Vec<String>,
+    pub supp_var: Vec<String>,
 }
 
 impl Display for Table {
@@ -39,8 +39,8 @@ impl Clone for Table {
     fn clone(&self) -> Table {
         Table {
             table: self.table.clone(),
-            supp_var: self.supp_var.clone(),
             base_var: self.base_var.clone(),
+            supp_var: self.supp_var.clone(),
         }
     }
 }
@@ -78,8 +78,8 @@ impl Table {
         supp_var.push("F".to_string());
         Table {
             table: constr_coeff,
-            supp_var,
             base_var,
+            supp_var,
         }
     }
     pub fn optimise(&mut self) -> Result<(), crate::SimplexError> {
@@ -149,7 +149,7 @@ impl Table {
         if let Some(i) = self.find_pivot_row(j) {
             debug!("Transforming on pivot i: {}\tj: {}", i, j);
             self.transform((i, j));
-            std::mem::swap(&mut self.supp_var[i], &mut self.base_var[j]);
+            std::mem::swap(&mut self.base_var[j], &mut self.supp_var[i]);
             return Ok(());
         } else {
             return Err(SimplexError::UnableToCalculateError);
@@ -160,7 +160,7 @@ impl Table {
         let (i, j) = self.find_pivot()?;
         debug!("Current pivot: i: {}\tj:{}", i, j);
         self.transform((i, j));
-        std::mem::swap(&mut self.supp_var[i], &mut self.base_var[j]);
+        std::mem::swap(&mut self.base_var[j], &mut self.supp_var[i]);
         Ok(())
     }
 
